/*
 * Copyright (c) @CompanyNameMagicTag 2020. All rights reserved.
 */

#ifndef __MNTN_PUBLIC_INTERFACE_H__
#define __MNTN_PUBLIC_INTERFACE_H__
#include "global_ddr_map.h"
#define RST_FLAG_MASK (0xFF)
#define PMU_RESET_VALUE_USED 0xFFFFFF00
#define BOOTUP_KEYPOINT_OFFSET (PMIC_HRST_REG14_ADDR(0))
#define PMU_RESET_RECORD_DDR_AREA_SIZE 0x100
#define RECORD_PC_STR_MAX_LENGTH 0x48
#define BOOT_EXCE_DIRTY_FLAG 0xA5A5A5A5
#define BOOT_EXCE_CLEAN_FLAG 0xF0F0F0F0
typedef struct {
	char exception_info[RECORD_PC_STR_MAX_LENGTH];
	unsigned long exception_info_len;
} ap_record_pc;
#define ETR_MAGIC_START "ETRTRACE"
#define ETR_MAGIC_SIZE ((unsigned int)sizeof(ETR_MAGIC_START))
#define LOGBUF_DUMP_MAGIC 0xFFEE5A5A
typedef struct {
	char magic[ETR_MAGIC_SIZE];
	unsigned long long paddr;
	unsigned int size;
	unsigned int rd_offset;
} ap_record_etr;
struct log_buf_dump_info {
	unsigned int magic;
	unsigned int reboot_reason;
	unsigned long long logbuf_addr;
	unsigned int logbuf_size;
	unsigned int idx_size;
	unsigned long long log_first_idx_addr;
	unsigned long long log_next_idx_addr;
};

enum boot_stage_point {
	STAGE_START = 1,
	STAGE_XLOADER_START = STAGE_START,
	STAGE_XLOADER_EMMC_INIT_FAIL = 2,
	STAGE_XLOADER_EMMC_INIT_OK = 3,
	STAGE_XLOADER_DDR_INIT_FAIL = 4,
	STAGE_XLOADER_DDR_INIT_OK = 5,
	STAGE_XLOADER_RD_VRL_FAIL = 6,
	STAGE_XLOADER_CHECK_VRL_ERROR = 7,
	STAGE_XLOADER_IMG_TOO_LARGE = 8,
	STAGE_XLOADER_READ_FASTBOOT_FAIL = 9,
	STAGE_XLOADER_LOAD_HIBENCH_FAIL = 10,
	STAGE_XLOADER_SEC_VERIFY_FAIL = 11,
	STAGE_XLOADER_GET_IMGSIZE_FAIL = 12,
	STAGE_XLOADER_IMGSIZE_ERROR = 13,
	STAGE_XLOADER_VRL_CHECK_ERROR = 14,
	STAGE_XLOADER_SECURE_VERIFY_ERROR = 15,
	STAGE_XLOADER_READ_UCE_FAIL = 16,
	STAGE_XLOADER_UCE_SEC_VERIFY_FAIL = 17,
	STAGE_XLOADER_UCE_SECURE_VERIFY_ERROR = 18,
	STAGE_XLOADER_XLOADER3_VERIFY_ERROR = 19,
	STAGE_XLOADER_VECTOR_SEC_VERIFY_FAIL = 20,
	STAGE_XLOADER_LOAD_FASTBOOT_START = 21,
	STAGE_XLOADER_LOAD_FASTBOOT_END = 22,
	STAGE_XLOADER_END = 25,
	STAGE_FASTBOOT_START = 26,
	STAGE_FASTBOOT_EMMC_INIT_START = 27,
	STAGE_FASTBOOT_EMMC_INIT_FAIL = 28,
	STAGE_FASTBOOT_EMMC_INIT_OK = 29,
	STAGE_FASTBOOT_DDR_INIT_START = 30,
	STAGE_FASTBOOT_DISPLAY_INIT_START = 31,
	STAGE_FASTBOOT_PRE_BOOT_INIT_START = 32,
	STAGE_FASTBOOT_LD_OTHER_IMGS_START = 33,
	STAGE_FASTBOOT_LD_KERNEL_IMG_START = 34,
	STAGE_FASTBOOT_BOOT_KERNEL_START = 35,
	STAGE_FASTBOOT_LOADLPMCU_FAIL = 38,
	STAGE_FASTBOOT_SECBOOT_INIT_START = 39,
	STAGE_FASTBOOT_END = 70,
	STAGE_KERNEL_EARLY_INITCALL = 75,
	STAGE_KERNEL_PURE_INITCALL = 77,
	STAGE_KERNEL_CORE_INITCALL = 79,
	STAGE_KERNEL_CORE_INITCALL_SYNC = 81,
	STAGE_KERNEL_POSTCORE_INITCALL = 83,
	STAGE_KERNEL_POSTCORE_INITCALL_SYNC = 85,
	STAGE_KERNEL_ARCH_INITCALL = 87,
	STAGE_KERNEL_ARCH_INITCALLC = 89,
	STAGE_KERNEL_SUBSYS_INITCALL = 81,
	STAGE_KERNEL_SUBSYS_INITCALL_SYNC = 83,
	STAGE_KERNEL_FS_INITCALL = 85,
	STAGE_KERNEL_FS_INITCALL_SYNC = 87,
	STAGE_KERNEL_ROOTFS_INITCALL = 89,
	STAGE_KERNEL_DEVICE_INITCALL = 91,
	STAGE_KERNEL_DEVICE_INITCALL_SYNC = 93,
	STAGE_KERNEL_LATE_INITCALL = 95,
	STAGE_KERNEL_LATE_INITCALL_SYNC = 97,
	STAGE_KERNEL_CONSOLE_INITCALL = 99,
	STAGE_KERNEL_SECURITY_INITCALL = 101,
	STAGE_KERNEL_BOOTANIM_COMPLETE = 103,
	STAGE_INIT_INIT_START = 110,
	STAGE_INIT_ON_EARLY_INIT = 111,
	STAGE_INIT_ON_INIT = 112,
	STAGE_INIT_ON_EARLY_FS = 113,
	STAGE_INIT_ON_FS = 114,
	STAGE_INIT_ON_POST_FS = 115,
	STAGE_INIT_ON_POST_FS_DATA = 116,
	STAGE_INIT_ON_EARLY_BOOT = 117,
	STAGE_INIT_ON_BOOT = 118,
	STAGE_ANDROID_ZYGOTE_START = 150,
	STAGE_ANDROID_VM_START = 151,
	STAGE_ANDROID_PHASE_WAIT_FOR_DEFAULT_DISPLAY = 152,
	STAGE_ANDROID_PHASE_LOCK_SETTINGS_READY = 153,
	STAGE_ANDROID_PHASE_SYSTEM_SERVICES_READY = 154,
	STAGE_ANDROID_PHASE_ACTIVITY_MANAGER_READY = 155,
	STAGE_ANDROID_PHASE_THIRD_PARTY_APPS_CAN_START = 156,
	STAGE_ANDROID_BOOT_SUCCESS = 250,
	STAGE_BOOTUP_END = STAGE_ANDROID_BOOT_SUCCESS,
	STAGE_END = 255,
};

#define MNTN_CTL_VALID_SIZE (0x40)  /* u64 */
enum mntnEnum {
	MNTN_CTL_NVE_VALID = 0,
	MNTN_CTL_EXTEND_LOG,
	MNTN_CTL_EXTEND_LOG_DISPLAY,
	MNTN_CTL_CON_LOG,      /* con log switch */
	MNTN_CTL_MNTN_DUMP,   /* kdump switch */
	MNTN_CTL_TEST_FUN,    /* test switch */
	MNTN_CTL_PLATFORM,
	MNTN_CTL_AP_WDT,
	MNTN_CTL_ISP_WDT,
	MNTN_CTL_IVP_WDT,
	MNTN_CTL_MMA_TRACE = 10,    /* media mem   trace switch */
	MNTN_CTL_MMA_TRACE_DISPLAY,  /* media mem   trace show uart */
	MNTN_CTL_RESERVED_WDT3,
	MNTN_CTL_WDT_MAX = MNTN_CTL_RESERVED_WDT3,
	MNTN_CTL_FST_DUMP_MEM,
	MNTN_CTL_MNTN_DUMP_MEM,
	MNTN_CTL_SD2JTAG,
	MNTN_CTL_PRESS_KEY_TO_FASTBOOT,
	MNTN_CTL_PANIC_INTO_LOOP,   /* OK */
	MNTN_CTL_GOBAL_RESETLOG,   /* save log */
	MNTN_CTL_NOC_INT_HAPPEN,
	MNTN_CTL_NOC_ERROR_REBOOT = 20,
	MNTN_CTL_DFXPARTITION_TO_FILE,  /* OK */
	MNTN_CTL_DDR_ERROR_REBOOT,
	MNTN_CTL_OUTSEE,
	MNTN_CTL_WATCHPOINT_EN,
	MNTN_CTL_KMEMLEAK_SWITCH,
	MNTN_CTL_FB_PANIC_REBOOT,
	MNTN_CTL_MEM_TRACE = 27,     /* OK */
	MNTN_CTL_FTRACE,
	MNTN_CTL_EAGLE_EYE,
	MNTN_CTL_KERNEL_DUMP_ENABLE = 30,   /* OK */
	MNTN_CTL_SD2DJTAG,
	MNTN_CTL_MMC_TRACE,
	MNTN_CTL_LPM3_PANIC_INTO_LOOP,
	MNTN_CTL_TRACE_CLK_REGULATOR,
	MNTN_CTL_CORESIGHT,
	MNTN_CTL_DMSSPT,
	MNTN_CTL_HHEE,
	MNTN_CTL_KASLR,
	MNTN_CTL_SD2UART6,
	MNTN_CTL_L3CACHE_ECC,
	MNTN_CTL_NOC_TRACE,
	MNTN_CTL_STM_TRACE,
	MNTN_CTL_AGING_WDT,
	MNTN_CTL_BOTTOM
};

#define DFX_HEAD_SIZE 512
#define TOTAL_NUMBER 5
#define FASTBOOTLOG_SIZE MNTN_SUB_RESERVED_FASTBOOT_LOG_PYHMEM_SIZE
#define LAST_KMSG_SIZE (MNTN_RESERVED_PSTORE_PHYMEM_SIZE / 2)
#define LAST_APPLOG_SIZE (MNTN_RESERVED_PSTORE_PHYMEM_SIZE / 8)
#define EVERY_NUMBER_SIZE (DFX_HEAD_SIZE + LAST_APPLOG_SIZE + LAST_KMSG_SIZE + FASTBOOTLOG_SIZE)
#define DFX_MAGIC_NUMBER 0x2846579
#define DFX_USED_SIZE (EVERY_NUMBER_SIZE*(TOTAL_NUMBER + 1)+DFX_HEAD_SIZE)
#define MNTN_LOG_TME_BASE (100)

struct dfx_head_info {
	int magic;
	char mntnctl[MNTN_CTL_VALID_SIZE];
	int total_number;
	int cur_number;
	int need_save_number;
	unsigned long long every_number_addr[TOTAL_NUMBER];
	unsigned long long every_number_size;
	unsigned long long temp_number_addr;
	unsigned long long log_time_base;
};
struct every_number_info {
	unsigned long long rtc_time;
	unsigned long long boot_time;
	unsigned long long bootup_keypoint;
	unsigned long long reboot_type;
	unsigned long long exce_subtype;
	unsigned long long fastbootlog_start_addr;
	unsigned long long fastbootlog_size;
	unsigned long long last_kmsg_start_addr;
	unsigned long long last_kmsg_size;
	unsigned long long last_applog_start_addr;
	unsigned long long last_applog_size;
};

typedef enum {
	AP_S_COLDBOOT = 0x0,
	BOOT_LOADER = 0x01,
	RECOVERY = 0x02,
	RESET_UART = 0x03,
	RESET_USER = 0x04,
	SD_UPDATE = 0x05,
	CHARGE_REBOOT = 0x06,
	RESIZE = 0x07,
	ERECOVERY = 0x08,
	USB_UPDATE = 0x09,
	CUST = 0x0a,
	AP_S_S4_COLDBOOT = 0x0b,
	OEM_RTC = 0x0c,
	UNKNOWN = 0x0d,
	MOUNT_FAIL = 0x0e,
	HUNG_DETECT = 0x0f,
	COLDBOOT = 0x10,
	UPDATE_DATA_IMG = 0x11,
	AT2_RESET_FACTORY = 0x12,
	AP_S_FASTBOOTFLASH = 0x13,
	AP_S_PRESS6S = 0x14,
	BR_UPDATE_USB = 0x15,
	BR_UPDATA_SD_FORCE = 0x16,
	BR_KEY_VOLUMN_UP = 0x17,
	BR_PRESS_1S = 0x18,
	BR_PRESS_10S = 0x19,
	BR_CHECK_RECOVERY = 0x1a,
	BR_CHECK_ERECOVERY = 0x1b,
	BR_CHECK_SDUPDATE = 0x1c,
	BR_CHECK_USBUPDATE = 0x1d,
	BR_CHECK_RESETFACTORY = 0x1e,
	BR_CHECK_HOTAUPDATE = 0x1f,
	BR_POWERONNOBAT = 0x20,
	BR_NOGUI = 0x21,
	BR_FACTORY_VERSION = 0x22,
	BR_RESET_HAPPEN = 0x23,
	BR_POWEROFF_ALARM = 0x24,
	BR_POWEROFF_CHARGE = 0x25,
	BR_POWERON_BY_SMPL = 0x26,
	BR_CHECK_UPDATEDATAIMG = 0x27,
	BR_REBOOT_CPU_BUCK = 0x28,
	BR_L2_CACHE_FAIL = 0x29,
	BR_POWERON_CHARGE = 0x2a,
	GPS_COLD_BOOT = 0x2b,
	ATF_FACTORY_RESET0 = 0x2c,
	FASTBOOTD = 0x2e,
	REBOOT_REASON_LABEL1 = 0x40,
	AP_S_ABNORMAL = REBOOT_REASON_LABEL1,
	AP_S_TSENSOR0 = 0x41,
	AP_S_TSENSOR1 = 0x42,
	AP_S_AWDT = 0x43,
	CHARGER_S_WDT = 0x44,
	G3D_S_G3DTSENSOR = 0x45,
	LPM3_S_LPMCURST = 0x46,
	CP_S_CPTSENSOR = 0x47,
	IOM3_S_IOMCURST = 0x48,
	ASP_S_ASPWD = 0x49,
	CP_S_CPWD = 0x4a,
	IVP_S_IVPWD = 0x4b,
	ISP_S_ISPWD = 0x4c,
	AP_S_DDR_UCE_WD = 0x4d,
	AP_S_DDR_FATAL_INTER = 0X4e,
	OCBC_S_WD = 0x4f,
	AP_S_PMU = 0x50,
	AP_S_SMPL = 0x51,
	AP_S_SCHARGER = 0x52,
	LPM3_S_EXCEPTION = 0x53,
	MMC_S_EXCEPTION = 0x54,
	AP_S_AHBTIMEOUT = 0x55,
	AP_S_TSENSOR2 = 0x56,
	REBOOT_REASON_LABEL2 = 0x60,
	AP_S_PANIC = REBOOT_REASON_LABEL2,
	AP_S_NOC = 0x61,
	AP_S_RESUME_SLOWY = 0x62,
	AP_S_DDRC_SEC = 0x63,
	AP_S_F2FS = 0x64,
	AP_S_COMBINATIONKEY = 0x65,
	AP_S_BL31_PANIC = 0x66,
	AP_S_MAILBOX = 0x67,
	AP_S_HHEE_PANIC = 0x68,
	AP_S_SUBPMU = 0x69,
	AP_S_VENDOR_PANIC = 0x6A,
	AP_S_OOM = 0x6B,
	AP_S_STANDBY = 0x6C,
	AP_S_CRASH = 0x6D,
	AP_S_SIMULATOR = 0x6E,
	AP_S_MMA = 0x6F,
	REBOOT_REASON_LABEL3 = 0x70,
	CP_S_EXCEPTION_START = REBOOT_REASON_LABEL3,
	CP_S_MODEMDMSS = CP_S_EXCEPTION_START,
	CP_S_GUCNAS_EXC = 0x81,
	CP_S_EXCEPTION_END = CP_S_GUCNAS_EXC,
	SOCHIFI_S_EXCEPTION = 0x82,
	HIFI_S_RESETFAIL = 0x83,
	ISP_S_EXCEPTION = 0x84,
	IVP_S_EXCEPTION = 0x85,
	IOM3_S_EXCEPTION = 0x86,
	TEE_S_EXCEPTION = 0x87,
	CODECHIFI_S_EXCEPTION = 0x88,
	IOM3_S_USER_EXCEPTION = 0x89,
	OUTSEE_S_EXCEPTION = 0x8a,
	NPU_S_EXCEPTION = 0x8b,
	WIFI_S_EXCEPTION = 0x8c,
	BFGX_S_EXCEPTION = 0x8d,
	AUDIO_CODEC_EXCEPTION = 0x8e,
	DDRWZ_S_EXCEPTION = 0x8f,
	REBOOT_REASON_LABEL4 = 0xa0,
	SBL_S_PANIC = REBOOT_REASON_LABEL4,
	SBL_S_CUSTOMINIT_FAIL = 0xa1,
	SBL_S_VERIFY_IMG_ERR = 0xa2,
	SBL_S_BOARDID_FAIL = 0xa3,
	SBL_S_MEDIAINIT_FAIL = 0xa4,
	UEFI_S_WATCHDOG = 0xa5,
	UEFI_S_PANIC = 0xa6,
	UEFI_S_GOP_FAIL = 0xa7,
	UEFI_S_GMAC_FAIL = 0xa8,
	UEFI_S_PCIE_FAIL = 0xa9,
	UEFI_S_UPGRADE_FAIL = 0xaa,
	UEFI_S_USB_FAIL = 0xab,
	UEFI_S_SATA_FAIL = 0xac,
	REBOOT_REASON_LABEL5 = 0xd0,
	BFM_S_NATIVE_BOOT_FAIL = REBOOT_REASON_LABEL5,
	BFM_S_BOOT_TIMEOUT,
	BFM_S_FW_BOOT_FAIL,
	BFM_S_NATIVE_DATA_FAIL,
	REBOOT_REASON_LABEL6 = 0xe0,
	REBOOT_REASON_INSTALL = 0xff,
} exch_source;

enum MODID_LIST {
	MNTN_BB_MOD_MODEM_DRV_START = 0x00000000,
	MNTN_BB_MOD_MODEM_DRV_END = 0x0fffffff,
	MNTN_BB_MOD_MODEM_OSA_START = 0x10000000,
	MNTN_BB_MOD_MODEM_OSA_END = 0x1fffffff,
	MNTN_BB_MOD_MODEM_OM_START = 0x20000000,
	MNTN_BB_MOD_MODEM_OM_END = 0x2fffffff,
	MNTN_BB_MOD_AP_START = 0x80000000,
	MNTN_BB_MOD_AP_END = 0x81fff0ff,
	MNTN_BB_MOD_BFM_START = 0x81fff100,
	MNTN_BB_MOD_BFM_END = 0x81fff1ff,
	MNTN_BB_MOD_FASTBOOT_START = 0x81fff200,
	MNTN_BB_MOD_FASTBOOT_END = 0x81fffcff,
	MNTN_BB_MOD_ISP_START = 0x81fffd00,
	MNTN_BB_MOD_ISP_END = 0x81fffeff,
	MNTN_BB_MOD_EMMC_START = 0x81ffff00,
	MNTN_BB_MOD_EMMC_END = 0x81ffffff,
	MNTN_BB_MOD_CP_START = 0x82000000,
	MNTN_BB_MOD_CP_END = 0x82ffffff,
	MNTN_BB_MOD_TEE_START = 0x83000000,
	MNTN_BB_MOD_TEE_END = 0x83ffffff,
	MNTN_BB_MOD_HIFI_START = 0x84000000,
	MNTN_BB_MOD_HIFI_END = 0x84ffffff,
	MNTN_BB_MOD_LPM_START = 0x85000000,
	MNTN_BB_MOD_LPM_END = 0x85ffffff,
	MNTN_BB_MOD_IOM_START = 0x86000000,
	MNTN_BB_MOD_IOM_END = 0x86ffffff,
	MNTN_BB_MOD_OUTSEE_START = 0x87000000,
	MNTN_BB_MOD_OUTSEE_END = 0x87ffffff,
	MNTN_BB_MOD_RESERVED_START = 0x88000000,
	MNTN_BB_MOD_RESERVED_END = 0x9fffffff,
	MNTN_BB_MOD_MODEM_LPS_START = 0xa0000000,
	MNTN_BB_MOD_MODEM_LPS_END = 0xafffffff,
	MNTN_BB_MOD_MODEM_LMSP_START = 0xb0000000,
	MNTN_BB_MOD_MODEM_LMSP_END = 0xbfffffff,
	MNTN_BB_MOD_NPU_START = 0xc0000000,
	MNTN_BB_MOD_NPU_END = 0xc0000fff,
	MNTN_BB_MOD_CONN_START = 0xc0001000,
	MNTN_BB_MOD_CONN_END = 0xc0001fff,
	MNTN_BB_MOD_IVP_START = 0xc0002000,
	MNTN_BB_MOD_IVP_END = 0xc0002fff,
	MNTN_BB_MOD_RANDOM_ALLOCATED_START = 0xd0000000,
	MNTN_BB_MOD_RANDOM_ALLOCATED_END = 0xf0ffffff
};

/* MODID_HIFI_S_ASPWDT->ASP_S_ASPWD(exch_source) */
typedef enum {
	MODID_HIFI_START = MNTN_BB_MOD_HIFI_START,
	MODID_ASP_S_ASPWD = 0x84000001,
	MODID_HIFI_S_OVERFLOW = 0x84000002,
	MODID_HIFI_END = MNTN_BB_MOD_HIFI_END
}modid_hifi;

typedef enum {
	MODID_CONN_START = MNTN_BB_MOD_CONN_START,
	MODID_WIFI_S_EXCEPTION = 0xc0001001,
	MODID_CONN_END = MNTN_BB_MOD_CONN_START
}modid_conn;

typedef enum {
	MODID_TEE_START = MNTN_BB_MOD_TEE_START,
	MODID_TEE_S_EXCEPTION = 0x83000001,
	MODID_TEE_END = MNTN_BB_MOD_TEE_END
}modid_tee;


enum CORE_LIST {
	RDR_AP = 0x1,
	RDR_CP = 0x2,
	RDR_TEEOS = 0x4,
	RDR_HIFI = 0x8,
	RDR_BL31 = 0x10,
	RDR_IOM3 = 0x20,
	RDR_ISP = 0x40,
	RDR_IVP = 0x80,
	RDR_EMMC = 0x100,
	RDR_MODEMAP = 0x200,
	RDR_CLK = 0x400,
	RDR_REGULATOR = 0x800,
	RDR_BFM = 0x1000,
	RDR_OUTSEE = 0x2000,
	RDR_NPU = 0x4000,
	RDR_CONN = 0x8000,
	RDR_EXCEPTION_TRACE = 0x10000,
	RDR_CORE_MAX = 17
};

typedef struct {
	unsigned long long magic;
	unsigned long long paddr;
	unsigned int size;
} ftrace_mdump_head;
#define DEV_DFX_PATH "/dev/block/by-name/dfx"
#define MNTNDUMP_MAGIC (0xDEADBEEFDEADBEEF)
#define MAX_LEN_OF_MNTNDUMP_ADDR_STR (0x20)
#define MNTN_DUMP_VERSION (0xFFFF0003)
typedef enum {
	MNTN_DUMP_HEAD,
	MNTN_DUMP_ETR,
	MNTN_DUMP_KERNEL_DUMP,
	MNTN_DUMP_PANIC,
	MNTN_DUMP_FTRACE,
	MNTN_DUMP_PSTORE_RAMOOPS,
	MNTN_DUMP_BC_PANIC,
	MNTN_DUMP_LOGBUF,
	MNTN_DUMP_HWDIAG,
	MNTN_DUMP_MAX
}mntn_dump_module;
#define MNTN_DUMP_HEAD_SIZE (sizeof(struct mdump_head))
#define MNTN_DUMP_ETR_SIZE (0x30)
#define MNTN_DUMP_KASLR_SIZE (0x10)
#define MNTN_DUMP_KERNEL_DUMP_SIZE (0x800)
#define MNTN_DUMP_PANIC_SIZE (0x100)
#define MNTN_DUMP_FTRACE_SIZE (0x30)
#define MNTN_DUMP_PSTORE_RAMOOPS_SIZE (0x30)
#define MNTN_DUMP_BC_PANIC_SIZE (0x20)
#define MNTN_DUMP_LOGBUF_SIZE (0x40)
#define MNTN_DUMP_HWDIAG_SIZE (0x100)
#define MNTN_DUMP_MAXSIZE (0x1000 - MNTN_DUMP_KASLR_SIZE)
struct mdump_regs_info {
	int mid;
	unsigned int offset;
	unsigned int size;
} ;
struct mdump_head {
	unsigned long magic;
	unsigned int version;
	unsigned int nums;
	struct mdump_regs_info regs_info[MNTN_DUMP_MAX];
};
struct mdump_end {
	unsigned long magic;
};
struct mdump_pstore {
	unsigned long magic;
	unsigned long ramoops_addr;
	unsigned long ramoops_size;
};

/**
 * exception trace core
 * EXCEPTION_TRACE_AP: exception come from whole system which be recorded in preserved memory
 * EXCEPTION_TRACE_BL31: exception come from bl31 which be recorded in preserved memory
 */
enum {
	EXCEPTION_TRACE_AP,
	EXCEPTION_TRACE_ENUM,
};

/**
 * exception trace for each core
 * @e_32k_time: record the 32k time when exception happen
 * @e_reset_core_mask: notify which core need to be reset, when include
 *  the ap core to be reset that will reboot the whole system
 * @e_from_core: exception triggered from which core
 * @e_exce_type: exception type
 * @e_exce_subtype: exception subtype
 */
typedef struct rdr_exception_trace_s {
	unsigned long long e_32k_time;
	unsigned long long e_reset_core_mask;
	unsigned long long e_from_core;
	unsigned int e_exce_type;
	unsigned int e_exce_subtype;
} rdr_exception_trace_t;


#endif
