/*
 * Copyright (c) @CompanyNameMagicTag 2020. All rights reserved.
 */

#ifndef __RDR_AP_RINGBUFFER_H__
#define __RDR_AP_RINGBUFFER_H__
#include <linux/kernel.h>
#include <linux/atomic.h>
#include <mntn/platform/mntn_public_interface.h>

#define BB_AP_KEYS_MAX  71
/* attention: must be aligned by 8, or it will data abort for unaligned data access */
typedef struct ap_ringbuffer_s {
	unsigned int max_num;
	unsigned int field_count;
	atomic_t rear; // write pointer, where the buffer is available to write in
	unsigned int r_idx; // read pointer, where the buffer is to be read
	unsigned int count; /* how many items in the buffer are not read  */
	unsigned int is_full;
	char keys[BB_AP_KEYS_MAX + 1]; /* For parsing with PC tools */
	unsigned char data[1];
} ap_ringbuffer_t;

#ifdef CONFIG_MNTN_BB
int rdr_ap_ringbuffer_init(struct ap_ringbuffer_s *q, u32 bytes,
	u32 fieldcnt, const char *keys);
void rdr_ap_ringbuffer_write(struct ap_ringbuffer_s *q, u8 *element, int len);
int rdr_ap_ringbuffer_read(struct ap_ringbuffer_s *q, u8 *element, u32 len);
int rdr_ap_is_ringbuffer_full(const void *buffer_addr);
void get_ringbuffer_start_end(struct ap_ringbuffer_s *q, u32 *start, u32 *end);
bool is_ringbuffer_empty(struct ap_ringbuffer_s *q);
bool is_ringbuffer_invalid(u32 field_count, u32 len, struct ap_ringbuffer_s *q);
#else
static inline int rdr_ap_ringbuffer_init(struct ap_ringbuffer_s *q, u32 bytes,
	u32 fieldcnt, const char *keys)
{
	return 0;
}
static inline void rdr_ap_ringbuffer_write(struct ap_ringbuffer_s *q, u8 *element, int len)
{
	return;
}
static inline int  rdr_ap_ringbuffer_read(struct ap_ringbuffer_s *q, u8 *element, u32 len)
{
	return 0;
}
static inline int  rdr_ap_is_ringbuffer_full(const void *buffer_addr)
{
	return 0;
}
static inline void get_ringbuffer_start_end(struct ap_ringbuffer_s *q, u32 *start, u32 *end)
{
	return;
}
static inline bool is_ringbuffer_empty(struct ap_ringbuffer_s *q)
{
	return true;
}
static inline bool is_ringbuffer_invalid(u32 field_count, u32 len, struct ap_ringbuffer_s *q)
{
	return true;
}
#endif

#endif
