/*
 * Copyright (c) @CompanyNameMagicTag 2020. All rights reserved.
 */
#ifndef __RDR_PLATFORM_H__
#define __RDR_PLATFORM_H__
#include <mntn/rdr_types.h>
#include <mntn/rdr_pub.h>
#include <mntn/platform/mntn_public_interface.h>

/* Confirm this definition is same as in the kernel/drivers/xxxx/modem/drv/om/dump/rdr_adp.h. */
#define RDR_MODEM_NOC_MOD_ID 0x82000030
#define RDR_MODEM_DMSS_MOD_ID 0x82000031
#define RDR_AUDIO_NOC_MODID 0x84000021

/* PMU register mask */
#define PMU_RESET_REG_MASK PMU_RESET_VALUE_USED

/* record log length */
#define LOG_PATH_LEN	96
#define DEST_LOG_PATH_LEN	(LOG_PATH_LEN + 10)
#define NEXT_LOG_PATH_LEN	(LOG_PATH_LEN + 30)


typedef enum {
	MODID_AP_START = MNTN_BB_MOD_AP_START,
	MODID_AP_S_PANIC = 0x80000001,
	MODID_AP_S_NOC = 0x80000002,
	MODID_AP_S_PMU = 0x80000003,
	MODID_AP_S_DDRC_SEC = 0x80000004,
	MODID_AP_S_SMPL = 0x80000005,
	MODID_AP_S_COMBINATIONKEY = 0x80000006,
	MODID_AP_S_SUBPMU = 0x80000007,
	MODID_AP_S_MAILBOX = 0x80000008,
	MODID_AP_S_SCHARGER = 0x80000009,
	MODID_AP_S_F2FS = 0x8000000a,
	MODID_AP_S_BL31_PANIC = 0x8000000b,
	MODID_AP_S_RESUME_SLOWY = 0x8000000c,
	MODID_CHARGER_S_WDT = 0x8000000d,
	MODID_AP_S_HHEE_PANIC = 0x8000000e,
	MODID_AP_S_WDT = 0x8000000f,
	MODID_AP_S_L3CACHE_ECC1 = 0x8000001e,
	MODID_AP_S_L3CACHE_ECC2 = 0x8000001f,
	MODID_AP_S_PANIC_SOFTLOCKUP = 0x80000020,
	MODID_AP_S_PANIC_OTHERCPU_HARDLOCKUP = 0x80000021,
	MODID_AP_S_PANIC_SP805_HARDLOCKUP = 0x80000022,
	MODID_AP_S_PANIC_SP805_WDG = 0x80000023,
	MODID_AP_S_PANIC_STORAGE = 0x80000024,
	MODID_AP_S_PANIC_ISP = 0x80000025,
	MODID_AP_S_PANIC_IVP = 0x80000026,
	MODID_AP_S_PANIC_GPU = 0x80000028,
	MODID_AP_S_PANIC_AUDIO_CODEC = 0x80000029,
	MODID_AP_S_OOM = 0x80000030,
	MODID_AP_S_TSENSOR0 = 0x80000031,
	MODID_AP_S_TSENSOR1 = 0x80000032,
	MODID_AP_S_TSENSOR2 = 0x80000033,
	MODID_AP_S_AHBTIMEOUT = 0x80000034,
	MODID_AP_S_UBSAN = 0x80000035,
	MODID_AP_S_STANDBY_S3_SUSPEND = 0x80000036,
	MODID_AP_S_STANDBY_S3_RESUME = 0x80000037,
	MODID_AP_S_STANDBY_S4_FREEZE = 0x80000038,
	MODID_AP_S_STANDBY_S4_THAW = 0x80000039,
	MODID_AP_S_STANDBY_S4_RESTORE = 0x8000003a,
	MODID_AP_S_STANDBY_SUSPEND = 0x8000003b,
	MODID_AP_S_STANDBY_RESUME = 0x8000003c,
	MODID_KASAN_UNKNOWN_CRASH = 0x8000003d,
	MODID_KASAN_OUT_OF_BOUNDS = 0x8000003e,
	MODID_KASAN_USE_AFTER_FREE  = 0x8000003f,
	MODID_KASAN_USE_AFTER_SCOPE = 0x80000040,
	MODID_KASAN_NULL_PTR_EDREF = 0x80000041,
	MODID_KASAN_USER_MEM_ACC = 0x80000042,
	MODID_KASAN_WILD_MEM_ACC = 0x80000043,
	MODID_KASAN_DOUBLE_FREE = 0x80000044,
	MODID_AP_S_ATOMIC_SLEEP  = 0x80000045,
	MODID_AP_S_LOCK_ERR  = 0x80000046,
	MODID_AP_S_LOCKDEP  = 0x80000047,
	MODID_AP_S_SIMULATOR  = 0x80000048,   /* dump platform logs */
	MODID_AP_S_DVFS_PANIC = 0x80000049,
	MODID_AP_S_DVFS_NOPANIC = 0x8000004a,
	MODID_DDRWZ_ILLEGAL_WRITE = 0x8000004b,

	MODID_AP_S_MMA_BEGIN  = 0x80002000,   /* reserved to mma */
	MODID_AP_S_MMA_END    = 0x80002fff,

	MODID_AP_S_VENDOR_BEGIN = 0x80100000,
	MODID_AP_S_VENDOR_END = 0x801fffff,

	MODID_AP_END = MNTN_BB_MOD_AP_END
} modid_ap;

typedef enum {
	MODU_NOC,
	MODU_DDR,
	MODU_TMC,
	MODU_MNTN_FAC,
	MODU_GAP,  /* 256 byte space as the gap, adding modules need before this */
	MODU_MAX
} dump_mem_module;


typedef int (*rdr_ap_dump_func_ptr) (void *dump_addr, unsigned int size);

#ifdef CONFIG_MNTN_BB

void save_module_dump_mem(void);
void regs_dump(void);
int register_module_dump_mem_func(rdr_ap_dump_func_ptr func,
	char *module_name, dump_mem_module modu);
int get_module_dump_mem_addr(dump_mem_module modu, unsigned char **dump_addr);
void set_exception_info(unsigned long address);
bool rdr_get_ap_init_done(void);
unsigned long long get_pmu_reset_reg(void);
int get_reboot_time(char *date, int len);
void set_reboot_reason(unsigned int reboot_reason);
unsigned int get_reboot_reason(void);
unsigned long long get_pmu_subtype_reg(void);
void set_subtype_exception(unsigned int subtype, bool save_value);
unsigned int get_subtype_exception(void);
char *rdr_get_subtype_name(u32 e_exce_type, u32 subtype);
const char *rdr_get_category_name(u32 e_exce_type, u32 subtype);
u32 rdr_get_exec_subtype_value(void);
char *rdr_get_exec_subtype(void);
void restore_exce_subtype(void);
void flush_logbuff_range(void);

#else
static inline void save_module_dump_mem(void)
{
	return;
}
static inline void regs_dump(void)
{
	return;
}
static inline void set_exception_info(unsigned long address)
{
	return;
}
static inline int register_module_dump_mem_func(rdr_ap_dump_func_ptr func,
	char *module_name, dump_mem_module modu)
{
	return -1;
}
static inline int get_module_dump_mem_addr(dump_mem_module modu,
	unsigned char *dump_addr)
{
	return -1;
}
static inline bool rdr_get_ap_init_done(void)
{
	return 0;
}
static inline void set_reboot_reason(unsigned int reboot_reason)
{
	return;
}
static inline unsigned int get_reboot_reason(void)
{
	return 0;
}
static inline void rdr_long_press_powerkey(void)
{
	return;
}
static inline void set_subtype_exception(unsigned int subtype, bool save_value)
{
	return;
}
static inline unsigned int get_subtype_exception(void)
{
	return 0;
}
static inline char *rdr_get_subtype_name(u32 e_exce_type, u32 subtype)
{
	return NULL;
}
static inline const char *rdr_get_category_name(u32 e_exce_type, u32 subtype)
{
	return NULL;
}
static inline u32 rdr_get_exec_subtype_value(void)
{
	return 0;
}
static inline char *rdr_get_exec_subtype(void)
{
	return NULL;
}
static inline void flush_logbuff_range(void)
{
	return;
}

#endif

#ifdef CONFIG_BB_REENTRANT_EXCEPTION
void reentrant_exception(void);
#else
static inline void reentrant_exception(void)
{
	return;
}
#endif

#ifdef CONFIG_MNTN_BB_DEBUG
void last_task_stack_dump(void);
void irq_register_hook(struct pt_regs *reg);
void show_irq_register(void);

#else
static inline void last_task_stack_dump(void)
{
	return;
}
static inline void irq_register_hook(struct pt_regs *reg)
{
	return;
}
static inline void show_irq_register(void)
{
	return;
}

#endif


#endif
