// SPDX-License-Identifier: GPL-2.0
/*
 * Copyright (c) HengShanCompany 2021-2021. All rights reserved.
 * Description: Interface export and extension within ION. And This
 *              header file should not be included by any source file
 *              except the internal ion file.
 * Author: HengShan
 * Create: 2020-05-24
 */

#ifndef __ION_INT_H__
#define __ION_INT_H__

#include "../drivers/staging/android/ion/ion.h"
#include <linux/dma-buf.h>
#include <linux/ion_uapi.h>

struct drv_ion_data {
	int tag_type;  /* 1: sec tag  0: no tag  */
	struct ion_buffer buffer;
	unsigned int sec_flag;  /* is the buffer secure? 1: secure 0 normal  */
	unsigned int agent_flag;  /* is the need to agent set? 0: need, 1 normal */
	phys_addr_t smmu_addr;
	phys_addr_t sec_smmu_addr;
	phys_addr_t phys_addr;
	struct dma_buf_attachment attachment;
	char name[BUFFER_NAME_MAX];
	struct dma_buf *dmabuf;
	phys_addr_t tee_mem_info;
	void *priv_data;
	size_t priv_len;
	unsigned long long sec_handle_id; /* sec mem handle id    */
	struct list_head list; /* manager ion_buffer  */
};

/************************ion.c****************************/
struct dma_buf *ion_heap_alloc(size_t len, unsigned int heap_id_mask,
			       unsigned int flags,
			       struct ion_buffer *drv_buffer);
void *drv_ion_buffer_kmap_get(struct ion_buffer *buffer);
void drv_ion_buffer_kmap_put(struct ion_buffer *buffer);
int drv_ion_dma_buf_attach(struct dma_buf *dmabuf,
			   struct dma_buf_attachment *attachment);
void drv_ion_dma_buf_detatch(struct dma_buf *dmabuf,
			     struct dma_buf_attachment *attachment);

/******************ion_system_heap.c***********************/
extern size_t g_ion_pool_limit;
struct ion_system_heap;

int drv_ion_system_heap_allocate(struct ion_heap *heap,
				 struct ion_buffer *buffer,
				 unsigned long size,
				 unsigned long flags);
void drv_ion_system_heap_free(struct ion_buffer *buffer);
int drv_ion_system_heap_shrink(struct ion_heap *heap, gfp_t gfp_mask,
			       int nr_to_scan);
struct ion_heap *__ion_system_heap_create(void);

/********************ion_cma_heap.c************************/
int drv_ion_cma_allocate(struct ion_heap *heap,
			 struct ion_buffer *buffer,
			 unsigned long len,
			 unsigned long flags);
void drv_ion_cma_free(struct ion_buffer *buffer);

/********************ion_page_pool.c************************/
struct page *drv_ion_page_pool_alloc_pages(struct ion_page_pool *pool);

/********************used in ion_cma_heap.c********************/
int set_cma_heap_data(struct cma *cma, struct ion_heap *heap);
int ion_cma_phys(struct ion_heap *heap, struct ion_buffer *buffer,
		 phys_addr_t *addr, size_t *len);
void set_ion_phys_addr(struct ion_buffer *buffer, phys_addr_t phys_addr);

/********************used in ion_system_heap.c********************/
int ion_heap_map_ree_iommu(struct ion_buffer *buffer,
			   struct ion_iommu_map *map_data);
void ion_heap_unmap_ree_iommu(struct ion_buffer *buffer,
			      struct ion_iommu_map *map_data);
struct page *drv_alloc_buffer_page(struct ion_system_heap *heap,
				   struct ion_buffer *buffer,
				   unsigned long order);

/********************used in ion.c****************************/
void drv_ion_ext_init(struct ion_device *idev);
struct drv_ion_data *init_ion_buf(const char *name, void *priv_data,
				  size_t priv_len);
void del_buf(struct drv_ion_data *drv_data);
void add_buf(struct drv_ion_data *drv_data);
dma_addr_t ion_dma_iommu_map(struct dma_buf *dmabuf, unsigned long offset);
int ion_dma_iommu_unmap(struct dma_buf *dmabuf, unsigned long offset, dma_addr_t iova);
dma_addr_t ion_dma_sec_iommu_map(struct dma_buf *dmabuf, unsigned long offset);
int ion_dma_sec_iommu_unmap(struct dma_buf *dmabuf, unsigned long offset, dma_addr_t iova);
phys_addr_t ion_dma_phy(struct dma_buf *dmabuf);
struct dma_buf *drv_get_dmabuf_by_tee_mem(phys_addr_t mem_info);
struct dma_buf *drv_get_dmabuf_by_addr(phys_addr_t addr, int memtype, phys_addr_t *base_addr);
struct dma_buf *drv_ion_get_dmabuf(phys_addr_t addr, size_t size, unsigned int heap_id);
void drv_add_heap_debugfs(struct ion_heap *heap);
void drv_dma_buf_relsease(struct dma_buf *dmabuf, struct ion_buffer *buffer);
void *drv_dma_buf_kmap(struct ion_buffer *buffer);
void drv_dma_buf_kunmap(struct ion_buffer *buffer);
void drv_build_sg(struct ion_buffer *buffer);
void set_priv_data(struct drv_ion_data *drv_data, const void *priv_data, size_t priv_len);
int is_priv_data(const struct dma_buf *dmabuf);
void ion_priv_data_free(struct dma_buf *dmabuf);
struct dma_buf *get_ion_priv_data_by_dma_buf(const struct dma_buf *dmabuf);
struct dma_buf *drv_ion_alloc_dmabuf_with_priv(size_t len, unsigned int heap_id_mask,
					       unsigned int flags, const char *name,
					       const void *ssm_data, size_t ssm_len,
					       size_t priv_len);

/***************used in ion-ioctl.c*******************/
struct dma_buf *drv_ion_alloc_dmabuf(size_t len, unsigned int heap_id_mask,
				     unsigned int flags, const char *name,
				     void *priv_data, size_t priv_len);
int drv_ion_alloc(size_t len, unsigned int heap_id_mask,
		  unsigned int flags, const char *name,
		  void *priv_data, size_t priv_len);
int drv_ion_alloc_with_priv(size_t len, unsigned int heap_id_mask,
			    unsigned int flags, const char *name,
			    const void *ssm_data, size_t ssm_len,
			    size_t priv_len);
int drv_get_ion_priv_data(int fd);

#endif
