// SPDX-License-Identifier: GPL-2.0
//
// ALSA SoC CX11880 codec driver
//
// Copyright:	(C) 2016 senarytech, Inc.
// Author:	bo liu, <bo.liu@senarytech.com>
//
// TODO: add support for TDM mode.
//
// Initially based on sound/soc/codecs/cx2072x.c
// Copyright:	(C) 2017 Conexant Systems, Inc.
// Author:	Simon Ho, <Simon.ho@conexant.com>
//

#ifndef __CX11880_H__
#define __CX11880_H__

// #define CX11880_RATES					SNDRV_PCM_RATE_8000_192000
#define CX11880_RATES					SNDRV_PCM_RATE_48000|SNDRV_PCM_RATE_96000|SNDRV_PCM_RATE_192000
#define CX11880_RATES_CAP				SNDRV_PCM_RATE_48000|SNDRV_PCM_RATE_96000
#define CX11880_RATES_PLAY			SNDRV_PCM_RATE_44100|SNDRV_PCM_RATE_96000|SNDRV_PCM_RATE_192000
#define CX11880_FORMATS					SNDRV_PCM_FMTBIT_S16_LE | SNDRV_PCM_FMTBIT_S24_LE

#define CX11880_REG_MAX					0xa3c8
//ROOT
#define CX11880_VENDOR_ID				0x0200
#define CX11880_REVISION_ID				0x0208
#define CX11880_SUBORDINATE_NODE_COUNT	0x0210
#define CX11880_BIT_CLOCK_CAPABILITIES	0x0258
#define CX11880_INTERFACE_CAPABILITIES	0x025c
#define CX11880_CURRENT_BCLK_FREQUENCY	0x00dc
#define CX11880_BOND_OPTION				0x0070
//AFG
#define CX11880_AFG_SUBORDINATE_NODE_COUNT	0x0610
#define CX11880_AFG_FUNCTION_GROUP_TYPE		0x0614
#define CX11880_AFG_CAPABILITIES		0x0620
#define CX11880_AFG_PCM_SIZE_RATE		0x0628
#define CX11880_AFG_PCM_FORMAT			0x062c
#define CX11880_AFG_SUPPORT_POWER_STATES	0x063c
#define CX11880_AFG_GPIO_COUNT			0x0644
#define CX11880_AFG_POWER_STATE			0x0414
#define CX11880_AFG_UNSOLICITED			0x0420
#define CX11880_AFG_GPIO_DATA			0x0454
#define CX11880_AFG_GPIO_ENABLE			0x0458
#define CX11880_AFG_GPIO_DIRECTION		0x045c
#define CX11880_AFG_GPIO_WAKE			0x0460
#define CX11880_AFG_GPIO_UM_ENABLE		0x0464
#define CX11880_AFG_GPIO_STICKY_MASK	0x0468
#define CX11880_AFG_CONFIG_DEFAULT		0x0470
#define CX11880_AFG_CONFIG_DEFAULT_1	0x0470
#define CX11880_AFG_CONFIG_DEFAULT_2	0x0471
#define CX11880_AFG_CONFIG_DEFAULT_3	0x0472
#define CX11880_AFG_CONFIG_DEFAULT_4	0x0473
#define CX11880_AFG_SUBSYSTEM_ID		0x0480
#define CX11880_AFG_SUBSYSTEM_ID_1		0x0480
#define CX11880_AFG_SUBSYSTEM_ID_2		0x0481
#define CX11880_AFG_SUBSYSTEM_ID_3		0x0482
#define CX11880_AFG_SUBSYSTEM_ID_4		0x0483
#define CX11880_AFG_SOFT_RESET			0x07fc
//DAC1
#define CX11880_DAC1_CONVERTER_FORMAT	0x43c8
#define CX11880_DAC1_AMP_GAIN_RIGHT		0x41c0
#define CX11880_DAC1_AMP_GAIN_LEFT		0x41e0
#define CX11880_DAC1_AUDIO_WIDGET		0x4224
#define CX11880_DAC1_PCM_SIZE_RATE		0x4228
#define CX11880_DAC1_PCM_FORMAT			0x422c
#define CX11880_DAC1_SUPPORT_POWER_STATES	0x423c
#define CX11880_DAC1_OUTPUT_AMP_CAPABILITIES	0x4248
#define CX11880_DAC1_POWER_STATE		0x4014
#define CX11880_DAC1_CONVERTER_STREAM_CHANNEL	0x4018
#define CX11880_DAC1_EAPD				0x4030
//DAC2
#define CX11880_DAC2_CONVERTER_FORMAT	0x47c8
#define CX11880_DAC2_AMP_GAIN_RIGHT		0x45c0
#define CX11880_DAC2_AMP_GAIN_LEFT		0x45e0
#define CX11880_DAC2_AUDIO_WIDGET		0x4624
#define CX11880_DAC2_PCM_SIZE_RATE		0x4628
#define CX11880_DAC2_PCM_FORMAT			0x462c
#define CX11880_DAC2_SUPPORT_POWER_STATES	0x463c
#define CX11880_DAC2_OUTPUT_AMP_CAPABILITIES	0x4648
#define CX11880_DAC2_POWER_STATE		0x4414
#define CX11880_DAC2_CONVERTER_STREAM_CHANNEL	0x4418
#define CX11880_DAC2_EAPD				0x4430
//PC Beep Generator
#define CX11880_BEEP_AMP_GAIN_LEFT		0x49e0
#define CX11880_BEEP_AUDIO_WIDGET		0x4a24
#define CX11880_BEEP_OUTPUT_AMP_CAPABILITIES	0x4a48
#define CX11880_BEEP_BEEP_GENERATION_CONTROL	0x4828
//ADC1
#define CX11880_ADC1_CONVERTER_FORMAT	0x4fc8
#define CX11880_ADC1_AMP_GAIN_RIGHT_0	0x4d80
#define CX11880_ADC1_AMP_GAIN_LEFT_0	0x4da0
#define CX11880_ADC1_AMP_GAIN_RIGHT_1	0x4d84
#define CX11880_ADC1_AMP_GAIN_LEFT_1	0x4da4
#define CX11880_ADC1_AMP_GAIN_RIGHT_2	0x4d88
#define CX11880_ADC1_AMP_GAIN_LEFT_2	0x4da8
#define CX11880_ADC1_AMP_GAIN_RIGHT_3	0x4d8c
#define CX11880_ADC1_AMP_GAIN_LEFT_3	0x4dac
#define CX11880_ADC1_AMP_GAIN_RIGHT_4	0x4d90
#define CX11880_ADC1_AMP_GAIN_LEFT_4	0x4db0
#define CX11880_ADC1_AUDIO_WIDGET		0x4e24
#define CX11880_ADC1_PCM_SIZE_RATE		0x4e28
#define CX11880_ADC1_PCM_FORMAT			0x4e2c
#define CX11880_ADC1_INPUT_AMP_CAPABILITIES	0x4e34
#define CX11880_ADC1_CONNECTION_LENGTH		0x4e38
#define CX11880_ADC1_SUPPORT_POWER_STATES	0x4e3c
#define CX11880_ADC1_CONNECTION_SELECT	0x4c04
#define CX11880_ADC1_CONNECTION_LIST	0x4d00
#define CX11880_ADC1_CONNECTION_LIST_4	0x4d04
#define CX11880_ADC1_POWER_STATE		0x4c14
#define CX11880_ADC1_CONVERTER_STREAM_CHANNEL	0x4c18
#define CX11880_ADC1_EAPD				0x4c30
//ADC2
#define CX11880_ADC2_CONVERTER_FORMAT	0x53c8
#define CX11880_ADC2_AMP_GAIN_RIGHT_0	0x5180
#define CX11880_ADC2_AMP_GAIN_LEFT_0	0x51a0
#define CX11880_ADC2_AMP_GAIN_RIGHT_1	0x5184
#define CX11880_ADC2_AMP_GAIN_LEFT_1	0x51a4
#define CX11880_ADC2_AMP_GAIN_RIGHT_2	0x5188
#define CX11880_ADC2_AMP_GAIN_LEFT_2	0x51a8
#define CX11880_ADC2_AUDIO_WIDGET		0x5224
#define CX11880_ADC2_PCM_SIZE_RATE		0x5228
#define CX11880_ADC2_PCM_FORMAT			0x522c
#define CX11880_ADC2_INPUT_AMP_CAPABILITIES	0x5234
#define CX11880_ADC2_CONNECTION_LENGTH		0x5238
#define CX11880_ADC2_SUPPORT_POWER_STATES	0x523c
#define CX11880_ADC2_CONNECTION_SELECT	0x5004
#define CX11880_ADC2_CONNECTION_LIST	0x5100
#define CX11880_ADC2_POWER_STATE		0x5014
#define CX11880_ADC2_CONVERTER_STREAM_CHANNEL	0x5018
#define CX11880_ADC2_EAPD				0x5030
//MIXER
#define CX11880_MIXER_AMP_GAIN_RIGHT_0	0x5580
#define CX11880_MIXER_AMP_GAIN_LEFT_0	0x55A0
#define CX11880_MIXER_AMP_GAIN_RIGHT_1	0x5584
#define CX11880_MIXER_AMP_GAIN_LEFT_1	0x55A4
#define CX11880_MIXER_AUDIO_WIDGET		0x5624
#define CX11880_MIXER_INPUT_AMP_CAPABILITIES	0x5634
#define CX11880_MIXER_CONNECTION_LENGTH	0x5638
#define CX11880_MIXER_SUPPORT_POWER_STATES	0x563C
#define CX11880_MIXER_CONNECTION_LIST	0x5500
#define CX11880_MIXER_POWER_STATE		0x5414
//PORTA
#define CX11880_PORTA_AUDIO_WIDGET		0x5a24
#define CX11880_PORTA_PIN_CAPABILITIES	0x5a30
#define CX11880_PORTA_CONNECTION_LENGTH	0x5a38
#define CX11880_PORTA_SUPPORT_POWER_STATES	0x5a3c
#define CX11880_PORTA_CONNECTION_SELECT	0x5804
#define CX11880_PORTA_CONNECTION_LIST	0x5900
#define CX11880_PORTA_POWER_STATE		0x5814
#define CX11880_PORTA_PIN_CTRL			0x581c
#define CX11880_PORTA_UNSOLICITED_RESPONSE	0x5820
#define CX11880_PORTA_PIN_SENSE			0x5824
#define CX11880_PORTA_EAPD				0x5830
#define CX11880_PORTA_DEFAULT_CONFIG	0x5870
//PORTG
#define CX11880_PORTG_AUDIO_WIDGET		0x5e24
#define CX11880_PORTG_PIN_CAPABILITIES	0x5e30
#define CX11880_PORTG_CONNECTION_LENGTH	0x5e38
#define CX11880_PORTG_SUPPORT_POWER_STATES	0x5e3c
#define CX11880_PORTG_CONNECTION_SELECT	0x5C04
#define CX11880_PORTG_CONNECTION_LIST	0x5d00
#define CX11880_PORTG_POWER_STATE		0x5C14
#define CX11880_PORTG_PIN_CTRL			0x5C1C
#define CX11880_PORTG_EAPD				0x5C30
#define CX11880_PORTG_DEFAULT_CONFIG	0x5c70
//PORTB
#define CX11880_PORTB_AMP_GAIN_RIGHT	0x6180
#define CX11880_PORTB_AMP_GAIN_LEFT		0x61A0
#define CX11880_PORTB_AUDIO_WIDGET		0x6224
#define CX11880_PORTB_PIN_CAPABILITIES	0x6230
#define CX11880_PORTB_INPUT_AMP_CAPABILITIES	0x6234
#define CX11880_PORTB_CONNECTION_LENGTH	0x6238
#define CX11880_PORTB_SUPPORT_POWER_STATES	0x623c
#define CX11880_PORTB_CONNECTION_SELECT	0x6004
#define CX11880_PORTB_CONNECTION_LIST	0x6100
#define CX11880_PORTB_POWER_STATE		0x6014
#define CX11880_PORTB_PIN_CTRL			0x601C
#define CX11880_PORTB_UNSOLICITED_RESPONSE	0x6020
#define CX11880_PORTB_PIN_SENSE			0x6024
#define CX11880_PORTB_EAPD				0x6030
#define CX11880_PORTB_DEFAULT_CONFIG	0x6070
//PORTD
#define CX11880_PORTD_AMP_GAIN_RIGHT	0x6580
#define CX11880_PORTD_AMP_GAIN_LEFT		0x65A0
#define CX11880_PORTD_AUDIO_WIDGET		0x6624
#define CX11880_PORTD_PIN_CAPABILITIES	0x6630
#define CX11880_PORTD_INPUT_AMP_CAPABILITIES	0x6634
#define CX11880_PORTD_SUPPORT_POWER_STATES	0x663c
#define CX11880_PORTD_POWER_STATE		0x6414
#define CX11880_PORTD_PIN_CTRL			0x641C
#define CX11880_PORTD_UNSOLICITED_RESPONSE	0x6420
#define CX11880_PORTD_PIN_SENSE			0x6424
#define CX11880_PORTD_DEFAULT_CONFIG	0x6470
//PORTC
#define CX11880_PORTC_AMP_GAIN_RIGHT	0x6980
#define CX11880_PORTC_AMP_GAIN_LEFT		0x69A0
#define CX11880_PORTC_AUDIO_WIDGET		0x6a24
#define CX11880_PORTC_PIN_CAPABILITIES	0x6a30
#define CX11880_PORTC_INPUT_AMP_CAPABILITIES	0x6a34
#define CX11880_PORTC_SUPPORT_POWER_STATES	0x6a3c
#define CX11880_PORTC_POWER_STATE		0x6814
#define CX11880_PORTC_PIN_CTRL			0x681C
#define CX11880_PORTC_UNSOLICITED_RESPONSE	0x6820
#define CX11880_PORTC_PIN_SENSE			0x6824
#define CX11880_PORTC_DEFAULT_CONFIG	0x6870
//DAC3
#define CX11880_DAC3_CONVERTER_FORMAT	0x83c8
#define CX11880_DAC3_AUDIO_WIDGET		0x8224
#define CX11880_DAC3_PCM_SIZE_RATE		0x8228
#define CX11880_DAC3_PCM_FORMAT			0x822c
#define CX11880_DAC3_SUPPORT_POWER_STATES	0x823c
#define CX11880_DAC3_POWER_STATE			0x8014
#define CX11880_DAC3_CONVERTER_STREAM_CHANNEL	0x8018
#define CX11880_DAC3_DIGITAL_CONVERTER_CTRL		0x8034  //TODO
//PORTI
#define CX11880_PORTI_AUDIO_WIDGET		0x8624
#define CX11880_PORTI_PIN_CAPABILITIES	0x8630
#define CX11880_PORTI_CONNECTION_LENGTH	0x8638
#define CX11880_PORTI_SUPPORT_POWER_STATES	0x863c
#define CX11880_PORTI_CONNECTION_LIST	0x8500
#define CX11880_PORTI_POWER_STATE		0x8414
#define CX11880_PORTI_PIN_CTRL			0x841c
#define CX11880_PORTI_DEFAULT_CONFIG	0x8470
//EQ
#define CX11880_EQ_ENABLE_BYPASS		0x6d00
#define CX11880_EQ_ENABLE_BYPASS_LSB	0x6d00
#define CX11880_EQ_ENABLE_BYPASS_MSB	0x6d01
#define CX11880_EQ_B0_COEFF				0x6d02
#define CX11880_EQ_B0_COEFF_LSB			0x6d02
#define CX11880_EQ_B0_COEFF_MSB			0x6d03
#define CX11880_EQ_B1_COEFF				0x6d04
#define CX11880_EQ_B1_COEFF_LSB			0x6d04
#define CX11880_EQ_B1_COEFF_MSB			0x6d05
#define CX11880_EQ_B2_COEFF				0x6d06
#define CX11880_EQ_B2_COEFF_LSB			0x6d06
#define CX11880_EQ_B2_COEFF_MSB			0x6d07
#define CX11880_EQ_A1_COEFF				0x6d08
#define CX11880_EQ_A1_COEFF_LSB			0x6d08
#define CX11880_EQ_A1_COEFF_MSB			0x6d09
#define CX11880_EQ_A2_COEFF				0x6d0a
#define CX11880_EQ_A2_COEFF_LSB			0x6d0a
#define CX11880_EQ_A2_COEFF_MSB			0x6d0b
#define CX11880_EQ_G_COEFF_REGISTER		0x6d0c
#define CX11880_EQ_BAND_CONTROL			0x6d0d
#define CX11880_EQ_BANK_CONTROL			0x6d0e
//SPKR DRC
#define CX11880_SPKR_DRC_ENABLE_STEP	0x6d10
#define CX11880_SPKR_DRC_FAST_RELEASE_UPDATE	0x6d11
#define CX11880_SPKR_DRC_BOOST			0x6d12
#define CX11880_SPKR_DRC_BALANCE_RAMP_STEP	0x6d13
#define CX11880_SPKR_DRC_VOLUME_RAMP_STEP	0x6d14
#define CX11880_SPKR_DRC_RELEASE_RATE	0x6d15
#define CX11880_SPKR_DRC_RELEASE_DELAY_PROG_SLOPE	0x6d16
#define CX11880_SPKR_DRC_MAX_LINEOUT	0x6d17
#define CX11880_SPKR_DRC_TEST			0x6d18
#define CX11880_SPKR_DRC_GAIN_LSB		0x6d19
#define CX11880_SPKR_DRC_GAIN_MSB		0x6d1a
//Digital Bios Test
#define CX11880_DIGITAL_BIOS_TEST0		0x6d80
#define CX11880_DIGITAL_BIOS_TEST0_LSB	0x6d80
#define CX11880_DIGITAL_BIOS_TEST0_MSB	0x6d81
#define CX11880_EAPD_CONTROL_LSB		0x6d82
#define CX11880_EAPD_CONTROL_MSB		0x6d83
#define CX11880_DIGITAL_BIOS_TEST2		0x6d84
#define CX11880_DIGITAL_BIOS_TEST2_LSB	0x6d84
#define CX11880_DIGITAL_BIOS_TEST2_MSB	0x6d85
#define CX11880_DIGITAL_BIOS_TEST3_LSB	0x6d86
#define CX11880_DIGITAL_BIOS_TEST3_MSB	0x6d87
#define CX11880_DIGITAL_BIOS_TEST4_LSB	0x6d88
#define CX11880_DIGITAL_BIOS_TEST4_MSB	0x6d89
#define CX11880_RC_OSC_LSB				0x6d8a
#define CX11880_RC_OSC_MSB				0x6d8b
#define CX11880_BIOS_DAC_ENV_DETECT		0x6d8f
#define CX11880_BIOS_MIC_MUTE_LSB		0x6d90
#define CX11880_BIOS_MIC_MUTE_MSB		0x6d91
#define CX11880_BIOS_EAPD_SPKMUTE_LSB	0x6d92
#define CX11880_BIOS_EAPD_SPKMUTE_MSB	0x6d93
#define CX11880_DIG_BIOS22				0x6e8c
#define CX11880_DIG_BIOS23				0x6e8d
#define CX11880_DIG_BIOS25				0x6e8f
#define CX11880_DIG_BIOS26				0x6e9c
#define CX11880_DIG_BIOS27				0x6e9d
#define CX11880_DIG_BIOS28				0x6e9e
//MBIST
#define CX11880_DAC_BIST_RAM_STATUS		0x6d9f
#define CX11880_ADC_BIST_RAM_STATUS		0x6da0
#define CX11880_BIST_RAM_START			0x6da1
#define CX11880_SRC_BIST_RAM_STATUS		0x6da2
#define CX11880_SRC_WS_BIST_RAM_STATUS	0x6da3
//I2SPCM
#define CX11880_I2SPCM_CONTROL1			0x6e00
#define CX11880_I2SPCM_CONTROL2			0x6e04
#define CX11880_I2SPCM_CONTROL3			0x6e08
#define CX11880_I2SPCM_CONTROL4			0x6e0c
#define CX11880_I2SPCM_CONTROL5			0x6e10
#define CX11880_I2SPCM_CONTROL6			0x6e18
#define CX11880_I2SPCM_CONTROL7			0x6e20
#define CX11880_I2SPCM_CONTROL8			0x6e24
#define CX11880_I2SPCM_CONTROL9			0x6e28
#define CX11880_I2SPCM_CONTROL10		0x6e2c
#define CX11880_NODE1B_I2C_ID			0x6e14
#define CX11880_NODE1B_I2C_CLK_CNT		0x6e16
#define CX11880_UM_INTERRUPT_CRTL		0x6e17
#define CX11880_I2C_UNSOL_INT_ST0		0x6e1c
#define CX11880_I2C_UNSOL_INT_ST1		0x6e1d
//CODEC TEST
#define CX11880_CODEC_TEST0				0x7100
#define CX11880_CODEC_TEST1				0x7104
#define CX11880_CODEC_TEST2				0x7108
#define CX11880_CODEC_TEST3				0x710C
#define CX11880_CODEC_TEST4				0x7110
#define CX11880_CODEC_TEST5				0x7114
#define CX11880_CODEC_TEST6				0x7118
#define CX11880_CODEC_TEST7				0x711C
#define CX11880_CODEC_TEST8				0x7120
#define CX11880_CODEC_TEST9				0x7124
#define CX11880_CODEC_TEST10			0x7128
#define CX11880_CODEC_TEST11			0x712C
#define CX11880_CODEC_TEST12			0x7130
#define CX11880_CODEC_TEST13			0x7134
#define CX11880_CODEC_TEST14			0x7138
#define CX11880_CODEC_TEST15			0x713C
#define CX11880_CODEC_TEST16			0x7300
#define CX11880_CODEC_TEST17			0x7304
#define CX11880_CODEC_TEST18			0x7308
#define CX11880_CODEC_TEST19			0x730C
#define CX11880_CODEC_TEST20			0x7310
#define CX11880_CODEC_TEST21			0x7314
#define CX11880_CODEC_TEST22			0x7318
#define CX11880_CODEC_TEST23			0x731C
#define CX11880_CODEC_TEST24			0x7320
#define CX11880_CODEC_TEST25			0x7324
#define CX11880_CODEC_TEST26			0x7328
#define CX11880_CODEC_TEST27			0x732C
#define CX11880_CODEC_TEST28			0x7330
#define CX11880_CODEC_TEST29			0x7334
#define CX11880_CODEC_TEST30			0x7338
#define CX11880_CODEC_TEST32			0x70a0
//Multi-Button/TR
#define CX11880_CODEC_TEST33			0x70a4
#define CX11880_CODEC_TEST34			0x70a8
#define CX11880_CODEC_TEST35			0x70ac
#define CX11880_CODEC_TEST36			0x70b0
#define CX11880_CODEC_TEST37			0x70b4
#define CX11880_CODEC_TEST38			0x70b8
#define CX11880_CODEC_TEST39			0x70bc
//Digital test
#define CX11880_DIGITAL_TEST0			0x7200
#define CX11880_DIGITAL_TEST1			0x7204
#define CX11880_DIGITAL_TEST2			0x7208
#define CX11880_DIGITAL_TEST3			0x720C
#define CX11880_DIGITAL_TEST4			0x7210
#define CX11880_DIGITAL_TEST5			0x7214
#define CX11880_DIGITAL_TEST6			0x7218
#define CX11880_DIGITAL_TEST7			0x721C
#define CX11880_DIGITAL_TEST8			0x7220
#define CX11880_DIGITAL_TEST9			0x7224
#define CX11880_DIGITAL_TEST10			0x7228
#define CX11880_DIGITAL_TEST11			0x722C
#define CX11880_DIGITAL_TEST12			0x7230
#define CX11880_DIGITAL_TEST13			0x7234
#define CX11880_DIGITAL_TEST14			0x7238
#define CX11880_DIGITAL_TEST15			0x723C
#define CX11880_DIGITAL_TEST16			0x7080
#define CX11880_DIGITAL_TEST17			0x7084
#define CX11880_DIGITAL_TEST18			0x7088
#define CX11880_DIGITAL_TEST19			0x708c
#define CX11880_DIGITAL_TEST20			0x7090
#define CX11880_DIGITAL_TEST21			0x7094
#define CX11880_DIGITAL_TEST22			0x7098
#define CX11880_DIGITAL_TEST23			0x709c
//Analog Codec Test
#define CX11880_ANALOG_TEST0			0x7180
#define CX11880_ANALOG_TEST1			0x7184
#define CX11880_ANALOG_TEST2			0x7188
#define CX11880_ANALOG_TEST3			0x718C
#define CX11880_ANALOG_TEST4			0x7190
#define CX11880_ANALOG_TEST5			0x7194
#define CX11880_ANALOG_TEST6			0x7198
#define CX11880_ANALOG_TEST7			0x719C
#define CX11880_ANALOG_TEST8			0x71A0
#define CX11880_ANALOG_TEST9			0x71A4
#define CX11880_ANALOG_TEST10			0x71A8
#define CX11880_ANALOG_TEST11			0x71AC
#define CX11880_ANALOG_TEST12			0x71B0
#define CX11880_ANALOG_TEST13			0x71B4
#define CX11880_ANALOG_TEST14			0x71B8
#define CX11880_ANALOG_TEST15			0x71BC
#define CX11880_ANALOG_TEST16			0x7280
#define CX11880_ANALOG_TEST17			0x7284

#define CX11880_MAX_EQ_BAND			7
#define CX11880_MAX_EQ_COEFF		11
#define CX11880_MAX_DRC_REGS		11

/* DAI interfae type */
#define CX11880_DAI_HIFI			1

/* Multi Button event */
#define MB_LP  0x00000080    //button long press
#define MB_MIC 0x00000040
#define MB_B4  0x00000020    //sw4,v-search
#define MB_B3  0x00000010    //sw3,vol-
#define MB_B2  0x00000008    //sw2,vol+
#define MB_B1  0x00000004    //sw1,ans,mut
#define MB_UP  0x00000002    //button up
#define MB_DN  0x00000001    //button down
#define MB_KEYTYPEMASK 0x3c

int cx11880_amixer_init(void);
unsigned int cx11880_get_spk_mute(void);
int cx11880_set_spk_unmute(void);
int cx11880_set_spk_mute(void);
int cx11880_reset(void);
int cx11880_set_power_d4(void);
#endif /* __CX11880_H__ */
